<?php

use TDevAgency\Cms\Middleware\AdminAccessMiddleware;
use TDevAgency\Erp\Controllers\Api\V1\ProductController;
use TDevAgency\Erp\Controllers\ContainerController;
use TDevAgency\Erp\Controllers\CustomerController;
use TDevAgency\Erp\Controllers\DeliveryController;
use TDevAgency\Erp\Controllers\OrderController;
use TDevAgency\Erp\Controllers\ProductsController;
use TDevAgency\Erp\Controllers\ManufactureController;
use TDevAgency\Erp\Controllers\ProviderController;
use TDevAgency\Erp\Middleware\ContainerMiddleware;

Route::middleware(AdminAccessMiddleware::class)->group(function () {
    Route::resource('containers', ContainerController::class);
});
Route::middleware(ContainerMiddleware::class)->group(function () {



    Route::resource('providers', ProviderController::class);
    Route::resource('orders', OrderController::class);
    Route::resource('customers', CustomerController::class);
    Route::resource('manufactures', ManufactureController::class);
    Route::resource('products', ProductsController::class);

    // Api endpoints
    Route::prefix('api')->as('api.')->group(function () {
        Route::prefix('v1')->as('v1.')->group(function () {
            Route::prefix('products')->as('products.')->group(function () {
                Route::get('{id}', [ProductController::class, 'show'])->name('show');
                Route::post('query', [ProductController::class, 'query'])->name('query');
            });
            Route::prefix('customers')->as('customers.')->group(function () {
                Route::post('query', [\TDevAgency\Erp\Controllers\Api\V1\CustomerController::class, 'query'])->name('query');
                Route::delete('addresses/{id}', [\TDevAgency\Erp\Controllers\Api\V1\CustomerController::class, 'deleteAddress'])->name('delete.address');
            });
            Route::prefix('nova-poshta')->as('nova-poshta.')->group(function () {
                Route::get('cities', [\TDevAgency\Erp\Controllers\Api\V1\NovaPoshta::class, 'cities'])->name('cities');
                Route::get('wire-houses', [\TDevAgency\Erp\Controllers\Api\V1\NovaPoshta::class, 'wireHouses'])->name('wire-house');
            });
            Route::prefix('deliveries')->as('deliveries.')->group(function () {
                Route::prefix('items')->as('items.')->group(function () {
                    Route::delete('{id?}', [\TDevAgency\Erp\Controllers\Api\V1\DeliveryController::class, 'deleteItem'])->name('delete');
                });
            });
        });
    });

    if (File::exists(base_path('routes/erp.php'))) {
        require_once base_path('routes/erp.php');
    }
});
